@@ -11,7 +11,7 @@ def test_create_tables(init_db):
 def test_create_with_comment(init_db):
     """注释功能"""
     db = init_db
-    db.dao_student_info.create_table()
+    db.dao_student_info._create_table()
 
 
 if __name__ == '__main__':
